@@ -43,6 +43,8 @@ def render_text(self, block: str, block_type: str, y: int) -> int:
         # create surface to get width of the word to identify necessary linebreaks
         word = word + " "
         if code_flag:
+            if position == 'first' or position == 'single':
+                x += self.code_padding
             surface = self.get_surface(word, 'code', bold_flag, italic_flag)
         else:
             surface = self.get_surface(word, block_type, bold_flag, italic_flag)
@@ -60,13 +62,16 @@ def render_text(self, block: str, block_type: str, y: int) -> int:
             self.draw_code_background(code_flag, word, x, y, position)
             self.screen.blit(surface, (x, y))
 
-        x = x + surface.get_width()  # update for next word
+        # Update x for the next word
+        x = x + surface.get_width()
+        if code_flag and position in ('single', 'last'):
+            x -= self.code_padding  # reduce empty space by padding.
 
-
-        # _________ FORMATTING RESET _________ #
+        # _________ FORMATTING RESET FOR NEXT WORD _________ #
         bold_flag = False if bold_flag and position == 'last' else bold_flag
-        code_flag = False if code_flag and position == 'last' else code_flag
+        code_flag = False if code_flag and (position == 'last' or position == 'single') else code_flag
         italic_flag = False if italic_flag and position == 'last' else italic_flag
+        position = 'Middle' if position == 'first' else position
 
     if block_type in ('h1', 'h2'):
         y = y + text_height * 0.5  # add an additional margin below h1 and h2 headers
